import Vue from 'vue'
import Router from 'vue-router'
import tableRouter from './modules/table'
Vue.use(Router)
/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: () => import('@/views/redirect/index')
      }
    ]
  },
  // {
  //   path: '/zyjh',
  //   component: () => import('@/views/jhzxgl/zyjh/index.vue'),
  //   hidden: true
  // },
  // {
  //   path: '/hbao',
  //   component: () => import('@/views/hbao/index'),
  //   hidden: true
  // },
  //看板
  {
    path: '/kban',
    component: () => import('@/views/kban/index'),
    hidden: true
  },
  //上料
  {
    path: '/sliao',
    component: () => import('@/views/zyjhzx/sliao/index'),
    hidden: true
  },
  //抛丸派工
  {
    path: '/pwpg',
    component: () => import('@/views/zyjhzx/pwanpgong/index'),
    hidden: true
  },
  //抛丸反馈
  {
    path: '/pwfk',
    component: () => import('@/views/zyjhzx/pwanfkui/index'),
    hidden: true
  },
  //理料派工
  {
    path: '/llpg',
    component: () => import('@/views/zyjhzx/lliaopgong/index'),
    hidden: true
  },
  //理料反馈
  {
    path: '/llfk',
    component: () => import('@/views/zyjhzx/lliaofkui/index'),
    hidden: true
  },
  //划线派工
  {
    path: '/hxpg',
    component: () => import('@/views/zyjhzx/hxianpgong/index'),
    hidden: true
  },
  //划线反馈
  {
    path: '/hxfk',
    component: () => import('@/views/zyjhzx/hxianfkui/index'),
    hidden: true
  },
  //切割派工
  {
    path: '/qgpg',
    component: () => import('@/views/zyjhzx/qgepgong/index'),
    hidden: true
  },
  //切割反馈
  {
    path: '/qgfk',
    component: () => import('@/views/zyjhzx/qgefkui/index'),
    hidden: true
  },
  //零件
  {
    path: '/ljian',
    component: () => import('@/views/zyjhzx/ljian/index'),
    hidden: true
  },
  {
    path: '/baogong',
    component: () => import('@/views/zyjhzx/ljian/baogong'),
    hidden: true
  },
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  }, {
    path: '/menu',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/auth-redirect',
    component: () => import('@/views/login/auth-redirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error-page/401'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [
      {
        path: 'dashboard',
        component: () => import('@/views/dashboard/index'),
        name: 'Dashboard',
        meta: { title: '系统首页', icon: 'dashboard', affix: true }
      }
    ]
  },


  {
    path: '/profile',
    component: Layout,
    redirect: '/profile/index',
    hidden: true,
    children: [
      {
        path: 'index',
        component: () => import('@/views/profile/index'),
        name: 'Profile',
        meta: { title: '个人主页', icon: 'user', noCache: true }
      }
    ]
  },
  // tableRouter
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
